@@ -2,7 +2,6 @@ lib = File.expand_path('../../lib', __FILE__)
 $LOAD_PATH.unshift(lib) unless $LOAD_PATH.include?(lib)
 
 require 'simplecov'
-require 'coveralls'
 require 'minitest/autorun'
 require 'mocha/minitest'
 require 'faker'
@@ -12,5 +11,4 @@ require_relative 'strategy_test_case'
 
 SimpleCov.command_name 'test'
 SimpleCov.start
-Coveralls.wear!
 OmniAuth.config.test_mode = true
